@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Webmozart\Assert\Tests\StaticAnalysis;
 
 use Webmozart\Assert\Assert;
@@ -28,8 +30,6 @@ function nullOrStartsWith(?string $value, string $prefix): ?string
  * @psalm-pure
  *
  * @param iterable<string> $value
- *
- * @return iterable<string>
  */
 function allStartsWith(iterable $value, string $prefix): iterable
 {
@@ -42,8 +42,6 @@ function allStartsWith(iterable $value, string $prefix): iterable
  * @psalm-pure
  *
  * @param iterable<string|null> $value
- *
- * @return iterable<string|null>
  */
 function allNullOrStartsWith(iterable $value, string $prefix): iterable
 {
